@@ -12,5 +12,9 @@ from .concat_rois import concat_rois
 from .roi_calc_mw import roi_calc_mw
 from .json2tidycsv import json2tidycsv
 from .obtain_grand_m import obtain_grand_m
+from .concat_csv import concat_csv
+from .calc_dlc_mw import calc_dlc_mw
+from .recycle import trials, fwarnings
+from .dlcboxplot import dlcboxplot
 
 from .version import __version__, VERSION
