@@ -4,13 +4,13 @@ import json
 def json2tidycsv(json_file_loc, csv_output=False):
 
     # Converts dlc avgs data from JSON format to a tidy data in csv
-    #json_file_loc is the path to the json file with all individual avgs data
+    # json_file_loc is the path to the json file with all individual avgs data
 
     with open(json_file_loc) as json_file:
         data = json.load(json_file)
 
     param = [
-        'distance', 'vel', 'cat_distance', 'vel', 'acceleration', 'moving'
+        'distance', 'vel', 'cat_distance', 'acceleration', 'moving'
     ]
 
     trials = [
@@ -29,7 +29,7 @@ def json2tidycsv(json_file_loc, csv_output=False):
 
                     for z in param:
 
-                        if csv_output == True:
+                        if csv_output is True:
 
                             print(c + ',positive,' + z + ',' + x + ',' +
                                   str(data[i][c][x][z]),
